==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/ESIGNATURE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PASSWORD" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SIGNATURETYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CERTTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CERTNO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NOESIGNATURE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTERNALDATETIME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MFAPASSWORD" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTERNALUSERID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "userid",
    "password",
    "signaturetype",
    "certtype",
    "certno",
    "noesignature",
    "externaldatetime",
    "mfapassword",
    "externaluserid"
})
@XmlRootElement(name = "ESIGNATURE")
public class ESIGNATURE {

    @XmlElement(name = "USERID", required = true)
    protected USERID_Type userid;
    @XmlElement(name = "PASSWORD")
    protected String password;
    @XmlElement(name = "SIGNATURETYPE", required = true)
    protected String signaturetype;
    @XmlElement(name = "CERTTYPE")
    protected String certtype;
    @XmlElement(name = "CERTNO")
    protected String certno;
    @XmlElement(name = "NOESIGNATURE")
    protected String noesignature;
    @XmlElement(name = "EXTERNALDATETIME")
    protected DATETIME externaldatetime;
    @XmlElement(name = "MFAPASSWORD")
    protected String mfapassword;
    @XmlElement(name = "EXTERNALUSERID")
    protected String externaluserid;

    /**
     * Obtient la valeur de la propriété userid.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Définit la valeur de la propriété userid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

    /**
     * Obtient la valeur de la propriété password.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPASSWORD() {
        return password;
    }

    /**
     * Définit la valeur de la propriété password.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPASSWORD(String value) {
        this.password = value;
    }

    /**
     * Obtient la valeur de la propriété signaturetype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSIGNATURETYPE() {
        return signaturetype;
    }

    /**
     * Définit la valeur de la propriété signaturetype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSIGNATURETYPE(String value) {
        this.signaturetype = value;
    }

    /**
     * Obtient la valeur de la propriété certtype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCERTTYPE() {
        return certtype;
    }

    /**
     * Définit la valeur de la propriété certtype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCERTTYPE(String value) {
        this.certtype = value;
    }

    /**
     * Obtient la valeur de la propriété certno.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCERTNO() {
        return certno;
    }

    /**
     * Définit la valeur de la propriété certno.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCERTNO(String value) {
        this.certno = value;
    }

    /**
     * Obtient la valeur de la propriété noesignature.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNOESIGNATURE() {
        return noesignature;
    }

    /**
     * Définit la valeur de la propriété noesignature.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNOESIGNATURE(String value) {
        this.noesignature = value;
    }

    /**
     * Obtient la valeur de la propriété externaldatetime.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getEXTERNALDATETIME() {
        return externaldatetime;
    }

    /**
     * Définit la valeur de la propriété externaldatetime.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setEXTERNALDATETIME(DATETIME value) {
        this.externaldatetime = value;
    }

    /**
     * Obtient la valeur de la propriété mfapassword.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMFAPASSWORD() {
        return mfapassword;
    }

    /**
     * Définit la valeur de la propriété mfapassword.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMFAPASSWORD(String value) {
        this.mfapassword = value;
    }

    /**
     * Obtient la valeur de la propriété externaluserid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTERNALUSERID() {
        return externaluserid;
    }

    /**
     * Définit la valeur de la propriété externaluserid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTERNALUSERID(String value) {
        this.externaluserid = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/ESIGNATURE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PASSWORD" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SIGNATURETYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CERTTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CERTNO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NOESIGNATURE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTERNALDATETIME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MFAPASSWORD" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTERNALUSERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JSONWEBTOKEN" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "userid",
    "password",
    "signaturetype",
    "certtype",
    "certno",
    "noesignature",
    "externaldatetime",
    "mfapassword",
    "externaluserid",
    "jsonwebtoken"
})
@XmlRootElement(name = "ESIGNATURE")
public class ESIGNATURE {

    @XmlElement(name = "USERID", required = true)
    protected USERID_Type userid;
    @XmlElement(name = "PASSWORD")
    protected String password;
    @XmlElement(name = "SIGNATURETYPE", required = true)
    protected String signaturetype;
    @XmlElement(name = "CERTTYPE")
    protected String certtype;
    @XmlElement(name = "CERTNO")
    protected String certno;
    @XmlElement(name = "NOESIGNATURE")
    protected String noesignature;
    @XmlElement(name = "EXTERNALDATETIME")
    protected DATETIME externaldatetime;
    @XmlElement(name = "MFAPASSWORD")
    protected String mfapassword;
    @XmlElement(name = "EXTERNALUSERID")
    protected String externaluserid;
    @XmlElement(name = "JSONWEBTOKEN")
    protected String jsonwebtoken;

    /**
     * Gets the value of the userid property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Sets the value of the userid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

    /**
     * Gets the value of the password property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPASSWORD() {
        return password;
    }

    /**
     * Sets the value of the password property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPASSWORD(String value) {
        this.password = value;
    }

    /**
     * Gets the value of the signaturetype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSIGNATURETYPE() {
        return signaturetype;
    }

    /**
     * Sets the value of the signaturetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSIGNATURETYPE(String value) {
        this.signaturetype = value;
    }

    /**
     * Gets the value of the certtype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCERTTYPE() {
        return certtype;
    }

    /**
     * Sets the value of the certtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCERTTYPE(String value) {
        this.certtype = value;
    }

    /**
     * Gets the value of the certno property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCERTNO() {
        return certno;
    }

    /**
     * Sets the value of the certno property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCERTNO(String value) {
        this.certno = value;
    }

    /**
     * Gets the value of the noesignature property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNOESIGNATURE() {
        return noesignature;
    }

    /**
     * Sets the value of the noesignature property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNOESIGNATURE(String value) {
        this.noesignature = value;
    }

    /**
     * Gets the value of the externaldatetime property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getEXTERNALDATETIME() {
        return externaldatetime;
    }

    /**
     * Sets the value of the externaldatetime property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setEXTERNALDATETIME(DATETIME value) {
        this.externaldatetime = value;
    }

    /**
     * Gets the value of the mfapassword property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMFAPASSWORD() {
        return mfapassword;
    }

    /**
     * Sets the value of the mfapassword property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMFAPASSWORD(String value) {
        this.mfapassword = value;
    }

    /**
     * Gets the value of the externaluserid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTERNALUSERID() {
        return externaluserid;
    }

    /**
     * Sets the value of the externaluserid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTERNALUSERID(String value) {
        this.externaluserid = value;
    }

    /**
     * Gets the value of the jsonwebtoken property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJSONWEBTOKEN() {
        return jsonwebtoken;
    }

    /**
     * Sets the value of the jsonwebtoken property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJSONWEBTOKEN(String value) {
        this.jsonwebtoken = value;
    }

}
